/// <reference path='fourslash.ts'/>

////export interface Album<T> {
////   "artist": T;
////}
////var a: Album<number>;
////var /**/x = a['artist']; 

goTo.marker();
verify.quickInfoIs('var x: number');
